@@ -7,17 +7,16 @@ import ldap
 from ooldap import exceptions, Connection
 
 
-URI = os.environ['LDAP_CONNECTION_URI']
-BIND_DN = os.environ['LDAP_CONNECTION_DN']
-PASSWORD = os.environ['LDAP_CONNECTION_PASSWORD']
-
-
 log = getLogger('ooldap.foundation')
 
 
 class LDAPObject(object):
 
-    def __init__(self, dn, uri=URI, bind_dn=BIND_DN, password=PASSWORD):
+    def __init__(self,
+                 dn,
+                 uri=os.environ['LDAP_CONNECTION_URI'],
+                 bind_dn=os.environ['LDAP_CONNECTION_DN'],
+                 password=os.environ['LDAP_CONNECTION_PASSWORD']):
         self.dn = dn
         assert dn
         self.connection = Connection(uri, bind_dn, password)
@@ -32,11 +31,11 @@ class LDAPObject(object):
         type, data = self.connection.stream.result(result_id, 10)
         self.connection.unbind()
         if len(data) == 0:
-            log.error('%s not found in ldap' % self.dn)
             raise exceptions.ObjectNotFound
+            return None
         if len(data) > 1:
-            log.error('%s found multiple users in ldap' % self.dn)
             raise exceptions.MultipleObjectsFound
+            return None
         return data[0][1]
 
     def get_attribute(self, attribute):
