@@ -21,15 +21,11 @@ class Group(LDAPObject):
         add_group = ldap.modlist.addModlist(attr)
 
         self.connection.bind()
-
         try:
             log.debug('creating group %s' % self.dn)
             self.connection.stream.add_s(self.dn, add_group)
         except ldap.ALREADY_EXISTS:
             pass
-        except:
-            log.exception('Error creating group %s' % self.dn)
-
         self.connection.unbind()
 
     @property
@@ -43,8 +39,6 @@ class Group(LDAPObject):
                        [(ldap.MOD_ADD, 'member', str(new_member.dn))])
         except ldap.ALREADY_EXISTS:
             pass
-        except:
-            log.exception('Error adding %s to %s' % (new_member.dn, self.dn))
         self.connection.unbind()
 
     def remove_member(self, member):
@@ -54,6 +48,4 @@ class Group(LDAPObject):
                        [(ldap.MOD_DELETE, 'member', str(member.dn))])
         except ldap.NO_SUCH_OBJECT:
             pass
-        except:
-            log.exception('Error removing %s from %s' % (member.dn, self.dn))
         self.connection.unbind()
